==> yanmah2-1.5-noarch.zip: yanmah2-1.5-noarch/login.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2010 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php
define("HELLO","world");
require_once "product_definitions.php";
require_once "configurable_variables.php";
require_once "common_functions.php";
?>
<?php
require_once "init_processor.php";
session_regenerate_id(TRUE);
?>
<?php
$page_head = 'ログイン';
$lot_one = array("猫とラーメンのトリコ",
"邪神の眷族",
"鳥類の王",
"しなもんの使用人",
"タルト連合親善大使",
"どうやら",
"こくだランド環境大臣",
"仮面貴族",
"地獄の",
"青い空からやって来た",
"魔界倶楽部総裁",
"革命戦士",
"カレーに魅入られた",
"エアはてなスタッフの",
"愛媛県造形局長官",
"ロールちゃん広報担当",
"牛乳パックの",
"ステキな",
"人工無能",
"魔法少女",
"美少女戦士セーラー",
"ダンプ",
"キューティ",
"ねずみの世話人",
"カラアゲ食べたい",
"ブロック機能実装期成同盟の",
"イーグル",
"アンドレ・ザ・",
"ハルク・",
"グレート・",
"初代",
"二代目",
"三代目",
"東洋の巨人",
"魔法女装子",
"破壊王",
"ドロリッチ評論家",
"サンニコフ島元島民",
"火星人",
"木星人",
"エナガファンクラブ一号",
"日本やんまにの会の",
"エル・",
"ラ・",
"スペル・",
"キレイな",
"落ちている手袋研究家");
$lot_two = array("今日も元気に",
"今日もハイク、明日もハイク、これじゃ毎日",
"迷ったら",
"ホッと一息",
"朝から千本",
"何かあったら",
"宴に飽きたら",
"一人でいるなら",
"デスマーチでも",
"ネタにしたけりゃ",
"みんなも一緒に",
"そんなこと言っても",
"練習が終わったら",
"そうだ、京都へ行っても",
"月に代わって",
"試合に負けても",
"スクワット三千回分",
"やる気がなくても",
"てなこた忘れて",
"悲しくったってコートの中では平気なら",
"ドッドッドリフの",
"とりあえず",
"孫子曰く、",
"やや内角を狙い、えぐりこむように",
"正義のためなら鬼となるより",
"夢で逢えたら",
"何もなくても");
?>
<?php //セキュリティのための前処理。
checkNull($_GET);
checkNull($_POST);
checkNull($_COOKIE);
//不正なはてなID
if ($_POST["hatenaid"] != ''){
	checkId($_POST["hatenaid"]);
}
/*if ($_GET['return'] != ''){
	checkHttpUrl($_GET['return']);
}*/
?>
<?php
if (isset($_GET['return']) && $_GET['return'] != ''){
// 	$_SESSION['return'] = $_GET['return'];
// 	echo $_GET['return'].' ';
	$return = $_GET['return'];
// 	echo $return.' ';
// 	$return = rawurlencode($return);
// 	echo $return;
}
?>
<?php
if ($_GET['log'] == 'out'){
	$_SESSION = array();
	setcookie(session_name(),'',time()-999, dirname($_SERVER['SCRIPT_NAME']) . '/');
	session_destroy();
	$page_head = 'ログアウト';
	$page_phase = 'after';
} else {
  $page_phase = 'before';
}
?>
<?php
//var_dump($_POST['login']);
require 'login_processor.php';
$selfcall = htmlspecialchars($_SERVER["PHP_SELF"], ENT_QUOTES);
$safequery = htmlspecialchars($_SERVER["QUERY_STRING"], ENT_QUOTES);
$self_anchor = "http://{$_SERVER["SERVER_NAME"]}{$selfcall}";
$self_anchor_possibly_with_pagenum = $self_anchor;
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta http-equiv="Content-Style-Type" content="text/css" />
	<meta http-equiv="Content-Script-Type" content="text/javascript" />
	<?php echo "<title>{$page_head} - {$site_name}{$site_name_caption}</title>\n"; ?>
	<link rel="stylesheet" href="<?php echo $style_sheet; ?>" />
	<link rel="icon" href="./favicon.ico" type="image/vnd.microsoft.icon" />
	<link rel="shortcut icon" href="./favicon.ico" type="image/vnd.microsoft.icon" /></head>
<body>
<?php
echo '<div id="header" class="';
if ($_SESSION['auth'] === TRUE){
  echo 'user_timeline';
} else {
  echo 'default';
}
echo '"><h1>';
echo $page_head;
echo "</h1></div>\n";
?>
<hr />
<?php
// var_dump($acs_body);
// var_dump($_SESSION);
//var_dump($_SERVER['SERVER_NAME']);
//echo dirname($_SERVER['SCRIPT_NAME']);
//var_dump($_SESSION['password']);
//var_dump($session_cookie_expire);
if ($_SESSION['auth'] === TRUE){
/*	$_SESSION['hatenaid'] = $user_info['url_name'];
	$_SESSION['hatenaname'] = $user_info['display_name'];*/
	$phrase_1 = 'ログインしました。あなたは';
	$word_one = pullLot($lot_one);
	$phrase_2 = '（';
	$tag_1 = '<a href="./entries.php?user=';
	$tag_2 = '" class="hatena-id">';
	$phrase_3 = 'id:';
	$tag_3 = '</a>';
	$phrase_4 = '）として、はてなハイクに参加します。';
	$word_two = pullLot($lot_two);
	$tag_4 = '<a href="./entries.php?word='.$product_name_abbr.'&amp;body=';
	$tag_5 = '" class="navigation-link">';
	$phrase_5 = 'ハイクしよう。';
	$tag_6 = '</a>';
	echo '<p>' . $phrase_1 . $word_one . htmlspecialchars($_SESSION['hatenaname'],ENT_QUOTES) . $phrase_2 . $tag_1 . $_SESSION['hatenaid'] . $tag_2 . $phrase_3 . htmlspecialchars($_SESSION['hatenaid'],ENT_QUOTES) . $tag_3 .  $phrase_4 . $word_two . $tag_4 . rawurlencode('ログインしました。私は'.$word_one.$_SESSION['hatenaname'].$phrase_2.$phrase_3.$_SESSION['hatenaid'].$phrase_4.$word_two.$phrase_5." \n{$product_name_abbr} Ver.{$product_version} at http://".$_SERVER['SERVER_NAME'].dirname($_SERVER['PHP_SELF']).'/'."\n");
	if ($_GET['image'] == 'on') echo '&amp;image=on';
	echo $tag_5 . $phrase_5 . $tag_6 . '</p>';
	echo '<p>もし間違っている場合は、一旦<a href="./login.php?log=out" class="navigation-link">ログアウト</a>してください。</p>';
}

if ($error != ''){
  echo $error;
  echo "<pre>";
  var_dump($acstoken['trace']);
  echo "</pre>";
}
if ($_GET['log'] == 'out'){
	echo '<p>ログアウトしました。</p>';
}
?>
<?php
if (!isset($_SESSION['auth']) || $_SESSION['auth'] != TRUE){
	if ($return != ''){
		$return = rawurlencode($return);
	}
// var_dump($error);
	if ($error != ''){
	  echo $error;
	} else {
	  $login_url = "./login.php?with=haiku";
	  if ($return != '') $login_url = $login_url.'&return='.$return;
	  echo "<p><a href=\"{$login_url}\" class=\"navigation-link\">はてな OAuth 認証でログインする</a></p>";
	  echo $login_notice;
	}
}
?>
<hr />
<div>
<ul class="navigation-menu">
<?php
if ($_SESSION['auth'] === TRUE){
	if ($return != ''){
		if (preg_match("/.+\?.+/u", $return)){
// 			echo $return;
			echo '<li><a href="' . $return . '&amp;log=on';
// 			if ($_GET['image'] == 'on') echo '&amp;image=on';
			echo '" class="navigation-link">元のページ</a>に戻る</li>';
		} else {
			echo '<li><a href="' . $return . '?log=on';
// 			if ($_GET['image'] == 'on') echo '&amp;image=on';
			echo '" class="navigation-link">元のページ</a>に戻る</li>';
		}
		$return = '';
	}
}
?>
<?php
$navi_paging = FALSE;
$navi_imaging = FALSE;
require 'footer_include.php';
if (isset($_SESSION['oauth_stat'])){
  unset($_SESSION['oauth_stat']);
}
?>
<?php
if ($page_phase == 'before'){
if (!isset($_SESSION['auth']) || $_SESSION['auth'] === FALSE){
// if ($_SESSION['image'] != 'on'){
  $_SESSION = array();
  if (isset($_COOKIE[session_name()])){
	setcookie(session_name(), '', time() - 42000, dirname($_SERVER['SCRIPT_NAME']) . '/', $_SERVER["SERVER_NAME"]);
  }
  session_destroy();
// }
}
}
?>
</body>
</html>

==> yanmah2-1.6-noarch.zip: yanmah2-1.6-noarch/login.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2010 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php
define("HELLO","world");
require_once "product_definitions.php";
require_once "configurable_variables.php";
require_once "common_functions.php";
?>
<?php
require_once "init_processor.php";
session_regenerate_id(TRUE);
?>
<?php
$page_head = 'ログイン';
$lot_one = array("猫とラーメンのトリコ",
"邪神の眷族",
"鳥類の王",
"しなもんの使用人",
"タルト連合親善大使",
"どうやら",
"こくだランド環境大臣",
"仮面貴族",
"地獄の",
"青い空からやって来た",
"魔界倶楽部総裁",
"革命戦士",
"カレーに魅入られた",
"エアはてなスタッフの",
"ロールちゃん広報担当",
"牛乳パックの",
"ステキな",
"人工無能",
"魔法少女",
"美少女戦士セーラー",
"ダンプ",
"キューティ",
"ねずみの世話人",
"カラアゲ食べたい",
"ブロック機能実装期成同盟の",
"イーグル",
"アンドレ・ザ・",
"ハルク・",
"グレート・",
"初代",
"二代目",
"三代目",
"東洋の巨人",
"魔法女装子",
"破壊王",
"ドロリッチ評論家",
"サンニコフ島元島民",
"火星人",
"木星人",
"エナガファンクラブ一号",
"日本やんまにの会の",
"エル・",
"ラ・",
"スペル・",
"キレイな",
"落ちている手袋研究家",
"赤い仮面の");
$lot_two = array("今日も元気に",
"今日もハイク、明日もハイク、これじゃ毎日",
"迷ったら",
"ホッと一息",
"朝から千本",
"何かあったら",
"宴に飽きたら",
"一人でいるなら",
"デスマーチでも",
"ネタにしたけりゃ",
"みんなも一緒に",
"そんなこと言っても",
"練習が終わったら",
"そうだ、京都へ行っても",
"月に代わって",
"試合に負けても",
"スクワット三千回分",
"やる気がなくても",
"てなこた忘れて",
"悲しくったってコートの中では平気なら",
"ドッドッドリフの",
"とりあえず",
"孫子曰く、",
"やや内角を狙い、えぐりこむように",
"正義のためなら鬼となるより",
"夢で逢えたら",
"何もなくても",
"風の唸りに血が叫び力の限り");
?>
<?php //セキュリティのための前処理。
//不正なはてなID
if (isset($_POST["hatenaid"]) && $_POST["hatenaid"] != '') checkId($_POST["hatenaid"]);
/*if ($_GET['return'] != ''){
	checkHttpUrl($_GET['return']);
}*/
?>
<?php
if (isset($_GET['return']) && $_GET['return'] != ''){
// 	$_SESSION['return'] = $_GET['return'];
// 	echo $_GET['return'].' ';
	$return = $_GET['return'];
// 	echo $return.' ';
// 	$return = rawurlencode($return);
// 	echo $return;
}
?>
<?php
if (isset($_GET['log']) && $_GET['log'] == 'out'){
	$_SESSION = array();
	setcookie(session_name(),'',time()-999, dirname($_SERVER['SCRIPT_NAME']) . '/');
	session_destroy();
	$page_head = 'ログアウト';
	$page_phase = 'after';
} else {
  $page_phase = 'before';
}
?>
<?php
//var_dump($_POST['login']);
require 'login_processor.php';
$selfcall = htmlspecialchars($_SERVER["PHP_SELF"], ENT_QUOTES);
$safequery = htmlspecialchars($_SERVER["QUERY_STRING"], ENT_QUOTES);
$self_anchor = "http://{$_SERVER["SERVER_NAME"]}{$selfcall}";
$self_anchor_possibly_with_pagenum = $self_anchor;
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta http-equiv="Content-Style-Type" content="text/css" />
	<meta http-equiv="Content-Script-Type" content="text/javascript" />
	<?php echo "<title>{$page_head} - {$site_name}{$site_name_caption}</title>\n"; ?>
	<link rel="stylesheet" href="<?php echo $style_sheet; ?>" />
	<link rel="icon" href="./favicon.ico" type="image/vnd.microsoft.icon" />
	<link rel="shortcut icon" href="./favicon.ico" type="image/vnd.microsoft.icon" /></head>
<body>
<?php
echo '<div id="header" class="';
if (isset($_SESSION['auth']) && $_SESSION['auth'] === TRUE){
  echo 'user_timeline';
} else {
  echo 'default';
}
echo '"><h1>';
echo $page_head;
echo "</h1></div>\n";
?>
<hr />
<?php
// var_dump($acs_body);
// var_dump($_SESSION);
//var_dump($_SERVER['SERVER_NAME']);
//echo dirname($_SERVER['SCRIPT_NAME']);
//var_dump($_SESSION['password']);
//var_dump($session_cookie_expire);
if (isset($_SESSION['auth']) && $_SESSION['auth'] === TRUE){
/*	$_SESSION['hatenaid'] = $user_info['url_name'];
	$_SESSION['hatenaname'] = $user_info['display_name'];*/
	$phrase_1 = 'ログインしました。あなたは';
	$word_one = pullLot($lot_one);
	$phrase_2 = '（';
	$tag_1 = '<a href="./entries.php?user=';
	$tag_2 = '" class="hatena-id">';
	$phrase_3 = 'id:';
	$tag_3 = '</a>';
	$phrase_4 = '）として、はてなハイクに参加します。';
	$word_two = pullLot($lot_two);
	$tag_4 = '<a href="./entries.php?word='.$product_name_abbr.'&amp;body=';
	$tag_5 = '" class="navigation-link">';
	$phrase_5 = 'ハイクしよう。';
	$tag_6 = '</a>';
	echo '<p>' . $phrase_1 . $word_one . htmlspecialchars($_SESSION['hatenaname'],ENT_QUOTES) . $phrase_2 . $tag_1 . $_SESSION['hatenaid'] . $tag_2 . $phrase_3 . htmlspecialchars($_SESSION['hatenaid'],ENT_QUOTES) . $tag_3 .  $phrase_4 . $word_two . $tag_4 . rawurlencode('ログインしました。私は'.$word_one.$_SESSION['hatenaname'].$phrase_2.$phrase_3.$_SESSION['hatenaid'].$phrase_4.$word_two.$phrase_5." \n{$product_name_abbr} Ver.{$product_version} at http://".$_SERVER['SERVER_NAME'].dirname($_SERVER['PHP_SELF']).'/'."\n");
	if (isset($_GET['image']) && $_GET['image'] == 'on') echo '&amp;image=on';
	echo $tag_5 . $phrase_5 . $tag_6 . '</p>';
	echo '<p>もし間違っている場合は、一旦<a href="./login.php?log=out" class="navigation-link">ログアウト</a>してください。</p>';
} elseif (isset($_SESSION['auth']) && $_SESSION['auth'] == 'wait'){
  echo "<p>ログインできませんか？　<a href=\"./login.php?log=out\">もう一度試してみてください。</a></p>\n";
}

if (isset($error) && $error != ''){
  echo $error;
  echo "<pre>";
  var_dump($acstoken['trace']);
  echo "</pre>";
}
if (isset($_GET['log']) && $_GET['log'] == 'out'){
	echo '<p>ログアウトしました。</p>';
}
?>
<?php
if (!isset($_SESSION['auth']) || $_SESSION['auth'] != TRUE){
	if (isset($return) && $return != ''){
		$return = rawurlencode($return);
	}
// var_dump($error);
	if (isset($error) && $error != ''){
	  echo $error;
	} else {
	  $login_url = "./login.php?with=haiku";
	  if (isset($return) && $return != '') $login_url = $login_url.'&return='.$return;
	  echo "<p><a href=\"{$login_url}\" class=\"navigation-link\">はてな OAuth 認証でログインする</a></p>";
	  echo $login_notice;
	}
}
// var_dump($_SESSION['auth']);
?>
<hr />
<div>
<ul class="navigation-menu">
<?php
if (isset($_SESSION['auth']) && $_SESSION['auth'] === TRUE){
	if (isset($return) && $return != ''){
		if (preg_match("/.+\?.+/u", $return)){
// 			echo $return;
			echo '<li><a href="' . $return . '&amp;log=on';
// 			if ($_GET['image'] == 'on') echo '&amp;image=on';
			echo '" class="navigation-link">元のページ</a>に戻る</li>';
		} else {
			echo '<li><a href="' . $return . '?log=on';
// 			if ($_GET['image'] == 'on') echo '&amp;image=on';
			echo '" class="navigation-link">元のページ</a>に戻る</li>';
		}
		$return = '';
	}
}
?>
<?php
$navi_paging = FALSE;
$navi_imaging = FALSE;
require 'footer_include.php';
if (isset($_SESSION['oauth_stat'])){
  unset($_SESSION['oauth_stat']);
}
?>
<?php
if ($page_phase == 'before'){
if (!isset($_SESSION['auth']) || $_SESSION['auth'] === FALSE){
// if ($_SESSION['image'] != 'on'){
  $_SESSION = array();
  if (isset($_COOKIE[session_name()])){
	setcookie(session_name(), '', time() - 42000, dirname($_SERVER['SCRIPT_NAME']) . '/', $_SERVER["SERVER_NAME"]);
  }
  session_destroy();
// }
}
}
?>
</body>
</html>
